# Issues

Since I work offline quite often I'd like to track development of features and
bugs in the repository.

## Bugs

More important than features, we'll list these first.

## Features

Group by module and give each feature a level-4 heading.

### tournamentcontrol.competition

#### Record match official records on matches

Prior to a match taking place this forms the basis of the "appointments" by the
manager of the officials. Like allocating teams to a fixture grid we can ensure
that an official is not booked to appear in two places at once by mistake.

After the match we can record exactly who did appear in the match to form the
basis of the officials statistical record.

#### Add subsystem to record and report participant dismissals

At events where players are sent off there are often repurcussions to future
games. Sometimes immediately (automatic suspension in severe incidents) but
sometimes after accummulating several dismissals of a certain type.

To assist event managers we should collect this information and make it easily
reportable in the first instance, with a future expansion to make it possible
to trigger workflows to automate actions such as notifying team management of
need to appear at a judiciary or that a player has breached a limit and must be
stood down.
